@@ -12,6 +12,8 @@ import subprocess
 import sys
 import time
 import collections
+import chardet
+import requests
 from collections import OrderedDict
 from functools import wraps
 from ipaddress import ip_address, ip_network
@@ -19,10 +21,6 @@ from platform import machine
 from subprocess import call, Popen, PIPE
 from colorama.initialise import init as coloramainit
 from termcolor import colored
-
-import chardet
-import requests
-
 from pocsuite3.lib.core.convert import stdout_encode
 from pocsuite3.lib.core.data import conf
 from pocsuite3.lib.core.data import kb
@@ -448,25 +446,54 @@ def is_local_ip(ip_string):
     return ret
 
 
-def get_local_ip(all=False):
-    ips = list()
-    ips.append(get_host_ip())
-    try:
-        for interface in socket.getaddrinfo(socket.gethostname(), None):
-            ip = interface[4][0]
-            ips.append(ip)
-    except Exception:
-        pass
+def get_local_ip(all=True):
+    """Fetches all the local network address
+    """
+    ips = OrderedSet()
+    wan_ipv4 = get_host_ip()
+    ips.add(wan_ipv4)
+    if not all:
+        return list(ips)
 
-    ips = list(set(ips))
+    wan_ipv6 = get_host_ipv6()
+    if wan_ipv6:
+        ips.add(wan_ipv6)
 
-    return ips if all else ips.pop(0)
+    # fix https://github.com/BVLC/caffe/issues/861
+    os.environ["MPLBACKEND"] = "Agg"
+
+    # fix https://github.com/secdev/scapy/issues/3216
+    logging.getLogger("scapy").setLevel(logging.ERROR)
+
+    from scapy.all import WINDOWS, get_if_list, get_if_addr
+
+    if WINDOWS:
+        from scapy.all import IFACES
+        for iface in sorted(IFACES):
+            dev = IFACES[iface]
+            ips.add(dev.ip)
+    else:
+        for iface in get_if_list():
+            ipv4 = get_if_addr(iface)
+            if ipv4 != '0.0.0.0':
+                ips.add(ipv4)
+
+    return list(ips)
 
 
-def get_host_ip():
+def get_host_ip(dst='8.8.8.8'):
+    """ Fetches source ipv4 address when connect to dst
+
+    Args:
+        dst <str>: target ip or domain
+
+    Returns:
+        <str>:  source ip address
+    """
+
     try:
         s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-        s.connect(('8.8.8.8', 80))
+        s.connect((dst, 80))
         ip = s.getsockname()[0]
     except Exception:
         ip = '127.0.0.1'
@@ -797,7 +824,7 @@ def ltrim(text, char):
     return text
 
 
-def index_modules() -> list:
+def index_modules(modules_directory):
     """ Returns list of all exploits modules
 
     :param str modules_directory: path to modules directory
@@ -805,10 +832,9 @@ def index_modules() -> list:
     """
 
     modules = []
-    for root, dirs, files in os.walk(paths.POCSUITE_POCS_PATH):
-        _, package, root = root.rpartition("pocsuite3/pocs/".replace("/", os.sep))
+    for root, _, files in os.walk(modules_directory):
         files = filter(lambda x: not x.startswith("__") and x.endswith(".py"), files)
-        modules.extend(map(lambda x: os.sep.join((root, os.path.splitext(x)[0])), files))
+        modules.extend(map(lambda x: os.path.join(root, os.path.splitext(x)[0]), files))
 
     return modules
 
@@ -822,7 +848,7 @@ def humanize_path(path: str) -> str:
     :return str: humanized path
     """
 
-    return path.replace(".", "/")
+    return path.replace(".", os.sep)
 
 
 def pythonize_path(path: str) -> str:
@@ -834,7 +860,7 @@ def pythonize_path(path: str) -> str:
     :return str: pythonized path
     """
 
-    return path.replace("/", ".")
+    return path.replace(os.sep, ".")
 
 
 def module_required(fn):
@@ -953,10 +979,19 @@ def encoder_powershell_payload(powershell: str):
     return command
 
 
-def get_host_ipv6():
+def get_host_ipv6(dst='2001:db8::'):
+    """ Fetches source ipv6 address when connect to dst
+
+    Args:
+        dst <str>: target ip or domain
+
+    Returns:
+        <str>:  source ipv6 address
+    """
+
     s = socket.socket(socket.AF_INET6, socket.SOCK_DGRAM)
     try:
-        s.connect(('2001:db8::', 1027))
+        s.connect((dst, 1027))
     except socket.error:
         return None
     return s.getsockname()[0]
