@@ -132,6 +132,8 @@ def cmd_line_parser(argv=None):
                                   help="Specify the name of the export rule file")
         # Diy options
         diy = parser.add_argument_group("Poc options", "definition options for PoC")
+        diy.add_argument("--options", dest="show_options", action="store_true", default=False,
+                                  help="Show all definition options")
 
         for line in argv:
             if line.startswith("--"):
